@@ -16,7 +16,7 @@ namespace Syndication
 {
 namespace RDF
 {
-class Q_DECL_HIDDEN RDFVocab::RDFVocabPrivate
+class SYNDICATION_NO_EXPORT RDFVocab::RDFVocabPrivate
 {
 public:
     QString namespaceURI;
@@ -55,10 +55,7 @@ RDFVocab::RDFVocab()
     d->li = PropertyPtr(new Property(ns + QLatin1String("li")));
 }
 
-RDFVocab::~RDFVocab()
-{
-    delete d;
-}
+RDFVocab::~RDFVocab() = default;
 
 ResourcePtr RDFVocab::seq()
 {
